ValidationChain class

Constructors

ValidationChain(List<Validator> validators)
Validation Chain API
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validators → List<Validator>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(String? value) → String?
runs each Validator in the order they were specified.

Operators

operator ==(Object other) → bool
The equality operator.
inherited